@@ -3,7 +3,7 @@ package URI::_db;
 use strict;
 use 5.008001;
 use base 'URI::_login';
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub uri    { shift }
 sub _no_scheme_ok { 0 }
@@ -33,7 +33,7 @@ sub has_recognized_engine {
 
 sub dbname {
     my $self = shift;
-    my $is_full = $self->opaque =~ m{^//(?://|(?!/))};
+    my $is_full = $self->opaque =~ m{^//(?://|/?(?!/))};
     return $self->path($is_full && defined $_[0] ? "/$_[0]" : shift) if @_;
     my @segs = $self->path_segments or return;
     shift @segs if $is_full;
